'*****************************************************************************
'*  Name    : CalibrateProg.bas                                              *
'*  Author  : Gavin Wiggett                                                  *
'*  Notice  : Copyright (c) 2013 Bitfogav                                    *
'*          : All Rights Reserved                                            *
'*  Date    : 17/07/2013                                                     *
'*  Version : 1.1 Changed PPS pins configuration see (Onstartup) sub.	     *
'*  Version : 1.0 Release                                                    *
'*  Notes   : Record the Calibration values and edit the values under,       *
'*          : SetDefaultCal() in the tft Touch module.                       *
'*****************************************************************************

' set high speed clock and import modules...
clock = 80
imports Tft
imports TftGraphic
imports ComicSansMS
imports TftTouch

' program entry point...
Sub Main()
   WriteInstr()  
   CalibrateScreen(1) ' Top Left
   CalibrateScreen(2) ' Bottom Right       
   DisplayCalValues() ' display cal values                   
   do ' wait for user to touch screen
   loop until Touch.Available()           
   DrawMarkers()    
   dim x,y as ushort
   while true  
      if Touch.Available() then 
         Tft.Clear                                          
         DrawMarkers()
         Touch.Read()
         x = Touch.GetXPos()
         y = Touch.GetYPos()
         Tft.WriteAt(150,20, "X="+str(x)+" Y="+str(y))        
         delayms(800)
      end if                              
   end while
End Sub

' Display Cal values...
sub DisplayCalValues()
   Tft.Clear
   Tft.WriteAt(15, 5,  "*Calibration Values*")          
   Tft.WriteAt(15, 20, "X_TopLeft..........= "+ str(Calibrate.X_TopLeft))
   Tft.WriteAt(15, 32, "X_BottomRight....= "+str(Calibrate.X_BottomRight))
   Tft.WriteAt(15, 44, "Y_TopLeft..........= "+str(Calibrate.Y_TopLeft))
   Tft.WriteAt(15, 56, "Y_BottomRight....= "+str(Calibrate.Y_BottomRight))
   Tft.WriteAt(15, 76, "Calibration is complete.")
   Tft.WriteAt(15, 88, "Record values and edit TftTouch Module.")  
   Tft.WriteAt(15, 108,"Tap screen to continue to test.")
end sub

' testmarkers...
sub DrawMarkers()
   CrossHair(50,50)
   CrossHair(100,100)
   CrossHair(200,200)
   CornerMarker(1,0,0)
   CornerMarker(2,dispX-1,dispY-1)
end sub

' Calibrate Touch Screen...
sub CalibrateScreen(n as byte)
   dim counter as ushort = 0
   Tft.Clear
   select case n
      case 1 : CornerMarker(1,0,0)
      case 2 : CornerMarker(2,dispX-1,dispY-1)
   end select
   Tft.WriteAt((dispX/2)-15,(dispY/2)-10, "PRESS")
   do ' wait for user to touch screen
   loop until Touch.Available()
   Tft.Clear
   select case n
      case 1 : CornerMarker(1,0,0)
      case 2 : CornerMarker(2,dispX-1,dispY-1)
   end select
   Tft.WriteAt((dispX/2)-10,(dispY/2)-10, "HOLD") 
   do            
   Touch.Read()      ' keep reading touch screen values
   counter += 1
   loop until counter = 60 
   select case n 
      case 1 : Calibrate.X_TopLeft = TPos_Y : Calibrate.Y_TopLeft = TPos_X
      case 2 : Calibrate.X_BottomRight = TPos_Y : Calibrate.Y_BottomRight = TPos_X
   end select        
   Tft.Clear
   select case n
      case 1 : CornerMarker(1,0,0)
      case 2 : CornerMarker(2,dispX-1,dispY-1)
   end select
   Tft.WriteAt((dispX/2)-20,(dispY/2)-10, "RELEASE")
   do ' wait for user to release
   loop until not Touch.Available()
   delayms(500) 
end sub

' Write Instructions on start screen...
sub WriteInstr()
   Tft.Clear
   Tft.Brush.Style = BrushStyle.IsClear
   Tft.SetFont(ComicSansMS)
   Tft.WriteAt(25,50,"Use a stylus or something similar to touch as close")
   Tft.WriteAt(25,65,"to the corner of the selected corner marker as possible.")
   Tft.WriteAt(25,85,"Keep as still as possible and keep holding")
   Tft.WriteAt(25,100,"until told to release!.")
   Tft.WriteAt(25,120,"Repeat for both Top/Bottom.")
   Tft.WriteAt(25,140,"Do NOT use your finger as a calibration.")
   Tft.WriteAt(25,160,"Tap screen to continue.") 
   Tft.WriteAt((dispX/2)-60,(dispY)-15,"*TFT Touch Calibration*")
   do ' wait for user to touch screen
   loop until Touch.Available() 
   do ' wait for user to release
   loop until not Touch.Available()
   delayms(500) 
end sub

' Cross Hairs...
sub CrossHair(x as ushort, y as ushort)
  Tft.Rect(x-10, y-10, x+10, y+10)
  Tft.Line(x-5, y, x+5, y)
  Tft.Line(x, y-5, x, y+5)
end sub

' Corner Markers...
sub CornerMarker(n as byte, x as ushort, y as ushort)
   select case n  
      case 1 ' Top
      Tft.Line(x, y, x+10, y+10)
      Tft.Line(x, y, x+10, y)
      Tft.Line(x, y, x, y+10)
      case 2 ' Bottom
      Tft.Line(x, y, x-10, y-10)
      Tft.Line(x, y, x-10, y)
      Tft.Line(x, y, x, y-10)
   end select
end sub

' disable UART1 on pins D0 and D1...
sub OnStartup() Handles PIC.OnStartup
   RPINR18 = RPINR18 or &H001F  ' disable Uart1 RX
   RPOR2 = RPOR2 and &HE0FF     ' disable Uart1 TX
end sub

